#!/bin/sh
#
# Script to create oracle database

if [ $# -ne 1 ]
then
	echo "Usage: createdb.sh <database dir>"
	exit 1
fi

if [ "$ORACLE_HOME" = "" ]
then
	echo "$ORACLE_HOME"
	echo "You must set the ORACLE_HOME environment variable"
	exit 1
fi

if [ "$ORACLE_SID" = "" ]
then
	echo "$ORACLE_SID"
	echo "You must set the ORACLE_SID environment variable"
	exit 1
fi

####################
# Set the database and database directory vars
#####################
DB=${ORACLE_SID}
DB_DIR=$1

###################################################
# If the database already exists warn that we will 
# destroy it.
####################################################
if [ -f "$ORACLE_HOME"/dbs/init${DB}.ora  ]
then
	echo  "$ORACLE_HOME"/dbs/init${DB}.ora
	echo "Database already exists. Ok to destroy y/n ? \c"
	read junk
	if [ "$junk" != 'y' -a "$junk" != 'Y' ]
	then
		echo  "database create cancelled"
		exit 1
	fi
fi

####################################
# Check to see that the target database directory
# exists and has write permission.
####################################
if [ ! -d "$DB_DIR" ] 
then
	echo "$DB_DIR does not exist. Please create it first."
	exit 1
fi


########################################################
# Go and run the create_init.sh script
# to build the correct pfiles and .ora files for Oracle 
########################################################
echo "Creating the \$ORACLE_HOME/dbs .ora files ..."
create_init.sh $DB $DB_DIR

SYS=${DB_DIR}/sys_${DB}
SYS_AUX=${DB_DIR}/sysaux_${DB}
LOG1=/spec_log1
LOG2=/spec_log2
LOG3=/spec_log3
LOG4=/spec_log4
LOG5=/spec_log5
TEMP=${DB_DIR}/temp_${DB}
STATS=${DB_DIR}/stats_${DB}
UNDO=${DB_DIR}/undo_${DB}
UNDO1=${DB_DIR}/undo1_${DB}

# Create database

sqlplus <<EOT
CONNECT / as sysdba
shutdown;
startup nomount

CREATE DATABASE $DB
CONTROLFILE REUSE
LOGFILE GROUP 1 '${LOG1}' SIZE 5750M REUSE,
        GROUP 2 '${LOG2}' SIZE 5750M REUSE,
        GROUP 3 '${LOG3}' SIZE 5750M REUSE,
        GROUP 4 '${LOG4}' SIZE 5750M REUSE,
        GROUP 5 '${LOG5}' SIZE 5750M REUSE
MAXDATAFILES 256
DATAFILE '${SYS}' size 2000M REUSE
SYSAUX DATAFILE '${SYS_AUX}' size 2000M REUSE
DEFAULT TEMPORARY TABLESPACE temp_ts
    TEMPFILE '${TEMP}' SIZE 4096M REUSE
UNDO TABLESPACE undo_ts DATAFILE '${UNDO}'  SIZE 9000M REUSE,
                        DATAFILE '${UNDO1}' SIZE 9000M REUSE
    BLOCKSIZE 8K;

exit
EOT


echo "Running catalog scripts ..."
sqlplus <<EOT
CONNECT / as sysdba
@?/rdbms/admin/catalog;
@?/rdbms/admin/catexp.sql
@?/rdbms/admin/catldr.sql
@?/rdbms/admin/catproc.sql
@?/rdbms/admin/catparr.sql
@?/rdbms/admin/utlmontr;
EXIT
EOT

echo "Catalog done."

sqlplus <<EOT
CONNECT / as sysdba
CREATE USER spec IDENTIFIED BY spec;
GRANT CONNECT, RESOURCE TO spec;
GRANT ALL PRIVILEGES TO spec IDENTIFIED BY spec;

CREATE USER spec04 IDENTIFIED BY spec04;
GRANT CONNECT, RESOURCE TO spec04;
GRANT ALL PRIVILEGES TO spec04 IDENTIFIED BY spec04;

CREATE TABLESPACE stats_ts
        DATAFILE '${STATS}' SIZE 4096M REUSE
        EXTENT MANAGEMENT LOCAL UNIFORM SIZE 1M;

ALTER USER spec
	TEMPORARY TABLESPACE temp_ts;
ALTER USER spec04
	TEMPORARY TABLESPACE temp_ts;
EXIT
EOT
